@@ -7,15 +7,16 @@ Templates are initially read from .yml files and then kept as class.
 import re
 import dateparser
 import unicodedata
-import logging
+from logging import getLogger
+from pprint import pformat
 from collections import OrderedDict
 from . import parsers
 from .plugins import lines, tables
-# Area extraction is currently added for pdftotext and tesseract (which uses pdftotext)
-from ..input import pdftotext, tesseract
+# Area extraction is currently added for pdftotext, ocrmypdf and tesseract (which uses pdftotext)
+from ..input import pdftotext, ocrmypdf, tesseract
 from typing import Optional
 
-logger = logging.getLogger(__name__)
+logger = getLogger(__name__)
 
 OPTIONS_DEFAULT = {
     "remove_whitespace": False,
@@ -41,7 +42,7 @@ class InvoiceTemplate(OrderedDict):
     -------
     prepare_input(extracted_str)
         Input raw string and do transformations, as set in template file.
-    matches_input(optimized_str)
+    matches_input(extracted_str)
         See if string matches keywords set in template file
     parse_number(value)
         Parse number, remove decimal separator and add other options
@@ -59,12 +60,15 @@ class InvoiceTemplate(OrderedDict):
         # Merge template-specific options with defaults
         self.options = OPTIONS_DEFAULT.copy()
 
-        for lang in self.options["languages"]:
-            assert len(lang) == 2, "lang code must have 2 letters"
-
         if "options" in self:
             self.options.update(self["options"])
 
+        for lang in self.options["languages"]:
+            assert len(lang) == 2, (
+                "Error in Template %s lang code must have 2 letters"
+                % self["template_name"]
+            )
+
         # Set issuer, if it doesn't exist.
         if "issuer" not in self.keys():
             self["issuer"] = self["keywords"][0]
@@ -82,7 +86,7 @@ class InvoiceTemplate(OrderedDict):
 
         # Remove accents
         if self.options["remove_accents"]:
-            optimized_str = unicodedata.normalize('NFKD', optimized_str).encode('ascii', 'ignore').decode('ascii')
+            optimized_str = re.sub('[\u0300-\u0362]', '', unicodedata.normalize('NFKD', optimized_str))
 
         # Convert to lower case
         if self.options["lowercase"]:
@@ -90,40 +94,44 @@ class InvoiceTemplate(OrderedDict):
 
         # Specific replace
         for replace in self.options["replace"]:
-            assert len(replace) == 2, "A replace should be a list of exactly 2 elements."
+            assert len(replace) == 2, (
+                "Error in Template %s A replace should be a list of exactly 2 elements."
+                % self["template_name"]
+            )
             optimized_str = re.sub(replace[0], replace[1], optimized_str)
 
         return optimized_str
 
-    def matches_input(self, optimized_str: str) -> bool:
+    def matches_input(self, extracted_str: str) -> bool:
         """See if string matches all keyword patterns and no exclude_keyword patterns set in template file.
 
         Args:
-        optimized_str: String of the text from OCR of the pdf after applying options defined in the template.
+        extracted_str: String of the text from OCR of the pdf before applying options defined in the template.
 
         Return:
         Boolean
             - True if all keywords are found and none of the exclude_keywords are found.
             - False if either not all keywords are found or at least one exclude_keyword is found."""
 
-        if all([re.search(keyword, optimized_str) for keyword in self["keywords"]]):
+        if all([re.search(keyword, extracted_str) for keyword in self["keywords"]]):
             # All keyword patterns matched
             if self["exclude_keywords"]:
-                if any([re.search(exclude_keyword, optimized_str) for exclude_keyword in self["exclude_keywords"]]):
+                if any([re.search(exclude_keyword, extracted_str) for exclude_keyword in self["exclude_keywords"]]):
                     # At least one exclude_keyword matches
-                    logger.debug("Template: %s. Keywords matched. Exclude keyword found!", self["template_name"])
+                    logger.debug("Template: %s | Keywords matched. Exclude keyword found!", self["template_name"])
                     return False
             # No exclude_keywords or none match, template is good
-            logger.debug("Template: %s. Keywords matched. No exclude keywords found.", self["template_name"])
+            logger.debug("Template: %s | Keywords matched. No exclude keywords found.", self["template_name"])
             return True
         else:
-            logger.debug("Template: %s. Failed to match all keywords.", self["template_name"])
+            logger.debug("Template: %s | Failed to match all keywords.", self["template_name"])
             return False
 
     def parse_number(self, value):
-        assert (
-            value.count(self.options["decimal_separator"]) < 2
-        ), "Decimal separator cannot be present several times"
+        assert value.count(self.options["decimal_separator"]) < 2, (
+            "Error in Template %s Decimal separator cannot be present several times"
+            % self["template_name"]
+        )
         # replace decimal separator by a |
         amount_pipe = value.replace(self.options["decimal_separator"], "|")
         # remove all possible thousands separators
@@ -177,7 +185,7 @@ class InvoiceTemplate(OrderedDict):
             self.options["date_formats"],
         )
         logger.debug(
-            "Float parsing: decimal separator=%s", self.options["decimal_separator"]
+            "Float parsing: decimal separator=[%s]", self.options["decimal_separator"]
         )
         logger.debug("keywords=%s", self["keywords"])
         logger.debug(self.options)
@@ -191,7 +199,7 @@ class InvoiceTemplate(OrderedDict):
             # v is the value
             if isinstance(v, dict):
                 # Options were supplied to this field
-                if "area" in v and input_module in (pdftotext, tesseract):
+                if "area" in v and input_module in (pdftotext, ocrmypdf, tesseract):
                     # Area is currently only supported for pdftotext
                     # area is optional and re-extracts the text being searched
                     # This obviously has a performance impact, so use wisely
@@ -199,10 +207,9 @@ class InvoiceTemplate(OrderedDict):
                     logger.debug(f"Area was specified with parameters {v['area']}")
                     # Extract the text for the specified area
                     # Do NOT overwrite optimized_str. We're inside a loop and it will affect all other fields!
-                    optimized_str_area = input_module.to_text(invoice_file, v['area']).decode("utf-8")
+                    optimized_str_area = input_module.to_text(invoice_file, v['area'])
                     # Log the text
-                    logger.debug("START pdftotext area result ===========================")
-                    logger.debug(optimized_str_area)
+                    logger.debug("START pdftotext area result ===========================\n%s", optimized_str_area)
                     logger.debug("END pdftotext area result =============================")
                     optimized_str_for_parser = optimized_str_area
                 else:
@@ -217,11 +224,11 @@ class InvoiceTemplate(OrderedDict):
                         if value:
                             output[k] = value
                         else:
-                            logger.error("Failed to parse field %s with parser %s", k, v["parser"])
+                            logger.warning("Failed to parse field %s with parser %s", k, v["parser"])
                     else:
-                        logger.warning("Field %s has unknown parser %s set", k, v["parser"])
+                        logger.error("Field %s has unknown parser %s set", k, v["parser"])
                 else:
-                    logger.warning("Field %s doesn't have parser specified", k)
+                    logger.error("Field %s doesn't have parser specified", k)
             elif k.startswith("static_"):
                 logger.debug("field=%s | static value=%s", k, v)
                 output[k.replace("static_", "")] = v
@@ -261,7 +268,8 @@ class InvoiceTemplate(OrderedDict):
 
         if set(required_fields).issubset(output.keys()):
             output["desc"] = "Invoice from %s" % (self["issuer"])
-            logger.debug(output)
+            logger.debug("\n %s", pformat(output, indent=2))
+            # when python 3.7 support stops add sort_dicts=False,
             return output
         else:
             fields = list(set(output.keys()))
