@@ -4,9 +4,9 @@
 Pseudo-parser returning a static (predefined) value
 """
 
-import logging
+from logging import getLogger
 
-logger = logging.getLogger(__name__)
+logger = getLogger(__name__)
 
 
 def parse(template, field, settings, content):
@@ -14,6 +14,6 @@ def parse(template, field, settings, content):
         logger.warning("Field \"%s\" doesn't have static value specified", field)
         return None
 
-    logger.debug("field=%s | value=%s", field, settings["value"])
+    logger.debug("field=%s | value=['%s']", field, settings["value"])
 
     return settings["value"]
