@@ -17,13 +17,25 @@ try:
 except ImportError:
     from io import StringIO  # noqa: F401
 import unittest
+from unittest import mock
 
 from invoice2data.main import extract_data
-from invoice2data.input import pdftotext, tesseract, pdfminer_wrapper, pdfplumber
+from invoice2data.input import pdftotext, tesseract, pdfminer_wrapper, pdfplumber, ocrmypdf
 from invoice2data.output import to_csv, to_json, to_xml
 from .common import get_sample_files
 
 
+def have_pdfplumber():
+    try:
+        import pdfplumber  # noqa: F401
+    except ImportError:
+        return False
+    return True
+
+
+needs_pdfplumber = unittest.skipIf(not have_pdfplumber(), reason="requires pdfplumber\n")
+
+
 def _extract_data_for_export():
     pdf_files = get_sample_files('.pdf')
     for file in pdf_files:
@@ -87,6 +99,7 @@ class TestLIB(unittest.TestCase):
                 self.assertTrue(False, "pdfminer is not installed")
                 self.assertTrue(type(res) is str, "return is not a string")
 
+    @needs_pdfplumber
     def test_extract_data_pdfplumber(self):
         pdf_files = get_sample_files('.pdf')
         for file in pdf_files:
@@ -100,6 +113,18 @@ class TestLIB(unittest.TestCase):
             else:
                 self.assertTrue(True)
 
+    def test_have_ocrmypdf_unavailable(self):
+        with mock.patch.dict('sys.modules', {'ocrmypdf': None}):
+            have = ocrmypdf.have_ocrmypdf()
+            print("ocrmypdf should not be available have is %s" % have)
+            self.assertFalse(have, "ocrmypdf is NOT installed")
+
+    def test_haveocrmypdf_available(self):
+        with mock.patch.dict('sys.modules', {'ocrmypdf': True}):
+            have = ocrmypdf.have_ocrmypdf()
+            print("ocrmypdf should be available have is %s" % have)
+            self.assertTrue(have, "ocrmypdf is installed")
+
 
 if __name__ == '__main__':
     unittest.main()
